// hier Package-Definitioneinfuegen, z.B. package syntax;


import java.util.TreeMap;

/**
 * interface for communicating with the CDG-Parser
 */
public interface SyntaxDiagnose
{

    /**
     * analyses the german natural language user input
     * for grammatical correctnes
     * @param sentence the sentence input by user
     */
    public void analyze(String sentence);

    /**
     * the natural language sentence input by the user was correct
     * @return the sentence was correct
     */
    public boolean isCorrect();

    /**
     * gives an explanation for incorrect sentences
     * !!!return type may change!!!
     * @return explanation of the error containing a list of violations
     */
    public Explanation explanation();

    /**
     * evaluation of the quality of an input sentence
     * @return quality of input sentence - 0.0 if sentence was correct
     */
    public double quality();

    /**
     * returns syntax tree generated by the CDG-Parser
     * !!!return type may change!!!
     * @return the syntax tree generated by the CDG-Parser
     */
    public TreeMap syntaxTree();

}
